import React, { forwardRef, Ref, useImperativeHandle } from "react";
import styles from "./index.less";
import BaseModal from "@/components/BaseModal";
import { Flex, Space, Descriptions } from "antd";
import classNames from "classnames";
import { useBoolean } from "ahooks";

interface CardProps {
  title: string | React.ReactNode;
  w: number;
  h: number;
  style?: React.CSSProperties;
  className?: string;
  children: React.ReactNode;
}

const Card: React.FC<CardProps> = (props) => {
  const { title, children, w, h, style, className } = props;
  return (
    <div
      className={classNames(styles.card, className)}
      style={{ ...style, width: w, height: h }}
    >
      <div className={styles.cardTitle}>{title}</div>
      <div>{children}</div>
    </div>
  );
};

export type CleanRangeModalMethod = {
  show: () => void;
  hide: () => void;
};

interface RaiseDustModalProps {
  data?: any;
}

const RaiseDustModal = forwardRef<CleanRangeModalMethod, RaiseDustModalProps>(({ data }, ref) => {
  const [visible, action] = useBoolean(false);

  useImperativeHandle(ref, () => ({
    show: action.setTrue,
    hide: action.setFalse,
  }));

  return (
    <div className={styles.container}>
      <BaseModal
        open={visible}
        title={"扬尘监理"}
        onCancel={action.setFalse}
        width={1524}
      >
      <div className={styles.content}>
        <Flex gap={15}>
          <div>
            <Card w={879} h={179} title="">
              <div className={styles.indexWarp}>
                <div className={styles.cqiContent}>
                  <div className={styles.titleWarp}>
                    <span className={styles.cityName}>{data?.cityName || '成都市'}</span>
                    <span className={styles.title}>
                      实时空气质量指数（AQI）
                    </span>
                  </div>
                  <div className={styles.indexContent}>
                    <span className={styles.count}>{data?.aqi || 0}</span>
                    <span className={styles.tag}>{data?.aqiLevel || '优'}</span>
                  </div>
                </div>

                <div className={styles.pmWarp}>
                  <div className={styles.title}>主要污染物</div>
                  <div className={styles.content}>
                    {data?.pollutants?.map((item: any, index: number) => (
                      <div className={styles.pmCard} key={index}>
                        <div>
                          <span className={styles.total}>{item.value}</span>
                          <span>{item.unit}</span>
                        </div>
                        <div style={{ marginTop: 5 }}>{item.name}</div>
                      </div>
                    ))}
                  </div>
                </div>
              </div>
            </Card>
            <Card
              title={
                <div className={styles.cytitle}>
                  排放监管情况
                  <span className={styles.periodWarp}>近一周</span>
                </div>
              }
              style={{ marginTop: 20 }}
              w={879}
              h={560}
            >
              <div className={styles.dischargeWarp}>
                {(data?.dischargeStats || []).map((item: any, index: number) => (
                  <div className={styles.cardWarp} key={index}>
                    <span className={styles.count}>{item.value}</span>
                    <div>{item.name}</div>
                  </div>
                ))}
              </div>
            </Card>
          </div>
          <Card title="重点区域" w={566} h={761}>
            <div className={styles.areaWarp}>
              <img src={data?.keyArea?.image} alt="" className={styles.img} />
              <div className={styles.title}>
                {data?.keyArea?.name || '成都市轨道交能13号线一期公园大道站项目'}
              </div>
              <div className={styles.descWarp}>
                <Descriptions
                  column={1}
                  items={[
                    {
                      key: "1",
                      label: "巡检时间",
                      children: data?.keyArea?.inspectionTime,
                    },
                    {
                      key: "2",
                      label: "巡检人",
                      children: data?.keyArea?.inspector,
                    },
                    {
                      key: "3",
                      label: "现场PM10",
                      children: data?.keyArea?.pm10,
                    },
                    {
                      key: "4",
                      label: "现场PM2.5",
                      children: data?.keyArea?.pm25,
                    },
                    {
                      key: "5",
                      label: "现场AQI",
                      children: data?.keyArea?.aqi,
                    },
                    {
                      key: "6",
                      label: "是否合格",
                      children: data?.keyArea?.qualified ? '是' : '否',
                    },
                  ]}
                />
              </div>
            </div>
          </Card>
        </Flex>
        </div>
      </BaseModal>
    </div>
  );
});

export default RaiseDustModal;
