import React, { CSSProperties, forwardRef, Ref, useImperativeHandle, useMemo } from "react";
import styles from "./index.less";
import BaseModal from "@/components/BaseModal";
import { Flex, Space } from "antd";
import classNames from "classnames";
import { useBoolean } from "ahooks";
import TodayEvent from "../CleanRangeModal/components/TodayEvent";
import PieChart from "@/components/PieChart";
import ReactECharts from "echarts-for-react";
import { barOption } from "./option";
import { cloneDeep } from "lodash";

interface CardProps {
  title: string;
  w: number;
  h: number;
  style?: CSSProperties;
  className?: string;
  children: React.ReactNode;
}

const Card: React.FC<CardProps> = (props) => {
  const { title, children, w, h, style, className } = props;
  return (
    <div
      className={classNames(styles.card, className)}
      style={{ ...style, width: w, height: h }}
    >
      <div className={styles.cardTitle}>{title}</div>
      <div>{children}</div>
    </div>
  );
};

export type CleanRangeModalMethod = {
  show: () => void;
  hide: () => void;
};

interface RefuseDisposalModalProps {
  data?: any;
}

const RefuseDisposalModal = forwardRef<CleanRangeModalMethod, RefuseDisposalModalProps>(({ data }, ref) => {
  const [visible, action] = useBoolean(false);

  useImperativeHandle(ref, () => ({
    show: action.setTrue,
    hide: action.setFalse,
  }));

  const newBarOption = useMemo(() => {
    if (!data?.incinerationData) return barOption;

    const xAxisData = data.incinerationData.map((item: any) => item.name);
    const seriesData = data.incinerationData.map((item: any) => ({
      value: item.value,
      name: item.name
    }));

    const temp = cloneDeep(barOption);
    (temp.series as any)[0].data = seriesData;
    (temp.xAxis as any)[0].data = xAxisData;
    return temp;
  }, [data]);

  return (
    <div className={styles.container}>
      <BaseModal
        open={visible}
        title={"垃圾处置"}
        onCancel={action.setFalse}
        width={1524}
      >
      <div className={styles.content}>
        <Flex gap={15}>
          <div>
            <Flex gap={20}>
              <Card title="昨日生活垃圾末端处置量" w={322} h={301}>
                <PieChart
                  chartOptions={{
                    title: {
                      text: `${data?.totalDisposal || 0}吨`,
                      subtext: "处理总量",
                      top: "35px",
                      x: "center",
                      textStyle: { color: "#6a738e", fontSize: 14 },
                      subtextStyle: {
                        color: "#6a738e",
                        fontSize: 10,
                      },
                    },
                  }}
                  style={{ width: "100%" }}
                  chartStyle={{ width: 118, height: 114 }}
                  vertical
                  labelClassName={styles.labelClassName}
                  data={[
                    {
                      name: "填埋量",
                      value: data?.landfillAmount || 0,
                      percent: data?.landfillPercent || "0",
                      type: 1,
                    },
                    {
                      name: "焚烧量",
                      value: data?.incinerationAmount || 0,
                      percent: data?.incinerationPercent || "0",
                      type: 2,
                    },
                  ]}
                />
              </Card>
              <Card title={data?.landfillInfo?.name} w={536} h={301}>
                {/* ... 填埋场信息展示 */}
                <div className={styles.landfillInfo}>
                    <img src={data?.landfillInfo?.image} alt="" className={styles.img} />
                    <div className={styles.laContent}>
                      {data?.landfillInfo?.description}
                    </div>
                  </div>
                  <div className={styles.card}>
                    <Flex justify="space-between" align="center">
                      <div>昨日生活垃圾填埋量</div>

                      <div>
                        <span className={styles.blueColor}>{data?.landfillInfo?.dailyAmount || 0}</span>吨
                      </div>
                    </Flex>
                  </div>
              </Card>
            </Flex>
            <Card
              title="生活垃圾焚烧环保发电厂"
              style={{ marginTop: 20 }}
              w={880}
              h={439}
            >
              <div className={styles.incinerationInfo}>
                {/* ... 焚烧厂信息展示 */}
                <div className={styles.infoContent}>
                    <div className={styles.cardInfo}>
                      <Flex justify="space-between" align="center">
                        <div>生活垃圾焚烧发电厂</div>

                        <div>
                          <span className={styles.blueColor}>{data?.factoryAmount || 0}</span>个
                        </div>
                      </Flex>
                    </div>
                    <div className={styles.cardInfo}>
                      <Flex justify="space-between" align="center">
                        <div>昨日焚烧量</div>

                        <div>
                          <span className={styles.blueColor}>{data?.yesterdayBurnAmount || 0}</span>吨
                        </div>
                      </Flex>
                    </div>
                  </div>
                  <div
                    style={{
                      color: "rgb(106, 115, 142)",
                      marginTop: 20,
                      marginBottom: 15,
                    }}
                  >
                    生活垃圾焚烧分厂处置量
                  </div>

                <ReactECharts
                  option={newBarOption}
                  style={{ width: 800, height: 180 }}
                />
              </div>
            </Card>
          </div>
          <Card title="保洁力量" w={566} h={761}>
            <TodayEvent data={data?.todayEvents || []} />
          </Card>
        </Flex>
        </div>
      </BaseModal>
    </div>
  );
});

export default RefuseDisposalModal;
