import React, { forwardRef, Ref, useImperativeHandle, useMemo } from "react";
import styles from "./index.less";
import BaseModal from "@/components/BaseModal";
import { Flex } from "antd";
import classNames from "classnames";
import { useBoolean } from "ahooks";
import MaintainCompany from "./components/MaintainCompany";
import ProgressBar from "@/pages/MunicipalFacilities/components/PipeModal/components/ProgressBar";
import ReactECharts from "echarts-for-react";
import { lineOption } from "./option";
import { CaretDownOutlined } from "@ant-design/icons";
import PieChart from "@/components/PieChart";
import FacilityInfoCard from "@/pages/MunicipalFacilities/components/PipeModal/components/FacilityInfoCard";
import { cloneDeep } from 'lodash';

interface DataCityManageModalProps {
  data?: any;
  onExport?: () => void;
}

interface CardProps {
  title: React.ReactElement | string;
  w: number;
  h: number;
  style?: React.CSSProperties;
  className?: string;
  children: React.ReactNode;
}

const Card: React.FC<CardProps> = (props) => {
  const { title, children, w, h, style, className } = props;
  return (
    <div
      className={classNames(styles.card, className)}
      style={{ ...style, width: w, height: h }}
    >
      <div className={styles.cardTitle}>{title}</div>
      <div>{children}</div>
    </div>
  );
};

export type CleanRangeModalMethod = {
  show: () => void;
  hide: () => void;
};

const DataCityManageModal = forwardRef<CleanRangeModalMethod, DataCityManageModalProps>(({ data, onExport }, ref) => {
  const [visible, action] = useBoolean(false);

  useImperativeHandle(ref, () => ({
    show: action.setTrue,
    hide: action.setFalse,
  }));

  const newLineOption = useMemo(() => {
    if (!data?.monthlyIssues?.trendData) return lineOption;
    const temp = cloneDeep(lineOption);
    const trendData = data.monthlyIssues.trendData;
    
    (temp.xAxis as any)[0].data = trendData.map((item: any) => item.date);
    (temp.series as any)[0].data = trendData.map((item: any) => item.value);
    
    return temp;
  }, [data]);

  return (
    <div className={styles.container}>
      <BaseModal
        open={visible}
        title={
          <Flex justify="space-between" style={{ width: "93%" }}>
            <span>数字城管常态监管</span>
            <span 
              style={{ fontSize: 18, color: "rgb(57, 136, 250)", cursor: 'pointer' }} 
              onClick={onExport}
            >
              导出报表
            </span>
          </Flex>
        }
        onCancel={action.setFalse}
        width={1524}
      >
        <div className={styles.content}>
          <Flex gap={15}>
            <div>
              <Card
                title={
                  <div>
                    {data?.monthlyIssues?.total || 0}月全市共发现城市管理类问题
                    <span className={styles.titleText}>{data?.monthlyIssues?.total || 0}</span>件
                  </div>
                }
                w={671}
                h={214}
              >
                <div className={styles.trend}>
                  <span>近半年投诉趋势</span>
                  <div className={styles.right}>
                    <span>较上月</span>
                    <span>
                      <CaretDownOutlined
                        style={{ color: data?.monthlyIssues?.trend > 0 ? "red" : "rgb(29, 187, 138)" }}
                      />
                    </span>
                    <span
                      style={{ 
                        color: data?.monthlyIssues?.trend > 0 ? "red" : "rgb(29, 187, 138)",
                        fontWeight: 600 
                      }}
                    >
                      {Math.abs(data?.monthlyIssues?.trend || 0)}
                    </span>
                    <span>%</span>
                  </div>
                </div>
                <ReactECharts
                  option={newLineOption}
                  style={{ width: 640, height: 120 }}
                />
              </Card>

              <Card
                title="事件主要类型"
                w={671}
                h={234}
                style={{ marginTop: 20 }}
              >
                <div className={styles.detailContent}>
                  {(data?.monthlyIssues?.mainTypes || []).map((item: any, index: number) => (
                    <div className={styles.areaItem} key={index}>
                      <span style={{ marginRight: 60 }}>{item.name}</span>
                      <ProgressBar
                        style={{ width: 300, height: 20, marginRight: 30 }}
                        value={item.count}
                        percent={item.percent?.toString()}
                        unit="件"
                      />
                    </div>
                  ))}
                </div>
              </Card>

              <Card
                title="事件来源分布"
                w={671}
                h={267}
                style={{ marginTop: 20 }}
              >
                <PieChart
                  style={{ width: "100%", marginTop: 30 }}
                  chartStyle={{ width: 144, height: 144 }}
                  labelGap={22}
                  labelClassName={styles.labelClassName}
                  data={data?.monthlyIssues?.sources || []}
                />
              </Card>
            </div>
            <div>
              <Card title="处置反馈情况" w={771} h={214}>
                <div className={styles.feedbackWarp}>
                  <FacilityInfoCard
                    style={{ height: 90, width: 221 }}
                    data={{
                      count: data?.disposalFeedback?.timelyRate || 0,
                      unit: "%",
                      label: "按时办结率"
                    }}
                  />
                  <FacilityInfoCard
                    style={{ height: 90, width: 221 }}
                    data={{
                      count: data?.disposalFeedback?.overtimeRate || 0,
                      unit: "%",
                      label: "超期率"
                    }}
                  />
                  <FacilityInfoCard
                    style={{ height: 90, width: 221 }}
                    data={{
                      count: data?.disposalFeedback?.satisfactionRate || 0,
                      unit: "%",
                      label: "满意率"
                    }}
                  />
                </div>
              </Card>
              <Card
                title="评价情况"
                style={{ marginTop: 20 }}
                w={771}
                h={525}
              >
                <MaintainCompany data={data?.evaluationRanking || []} />
              </Card>
            </div>
          </Flex>
        </div>
      </BaseModal>
    </div>
  );
});

export default DataCityManageModal;
